@@ -2,7 +2,7 @@ import unittest
 from libpysal.examples import load_example
 import geopandas as gpd
 import numpy as np
-from segregation.spatial import Delta
+from segregation.singlegroup import Delta
 
 
 class Delta_Tester(unittest.TestCase):
