@@ -2,7 +2,7 @@ import unittest
 from libpysal.examples import load_example
 import geopandas as gpd
 import numpy as np
-from segregation.aspatial import MultiDiversity
+from segregation.multigroup import MultiDiversity
 
 
 class Multi_Diversity_Tester(unittest.TestCase):
