@@ -2,15 +2,16 @@ import unittest
 from libpysal.examples import load_example
 import geopandas as gpd
 import numpy as np
-from segregation.spatial import PerimeterAreaRatioSpatialDissim
+from segregation.singlegroup import PARDissim
 
 
 class Perimeter_Area_Ratio_Spatial_Dissim_Tester(unittest.TestCase):
     def test_Perimeter_Area_Ratio_Spatial_Dissim(self):
         s_map = gpd.read_file(load_example("Sacramento1").get_path("sacramentot2.shp"))
         df = s_map[['geometry', 'HISP', 'TOT_POP']]
-        index = PerimeterAreaRatioSpatialDissim(df, 'HISP', 'TOT_POP')
-        np.testing.assert_almost_equal(index.statistic, 0.3111718061947464)
+        df = df.to_crs(df.estimate_utm_crs())
+        index = PARDissim(df, 'HISP', 'TOT_POP')
+        np.testing.assert_almost_equal(index.statistic, 0.3112698489030527, decimal=4)
 
 
 if __name__ == '__main__':
